@@ -734,7 +734,7 @@ _clutter_paint_volume_complete (ClutterPaintVolume *pv)
 /*<private>
  * _clutter_paint_volume_get_box:
  * @pv: a #ClutterPaintVolume
- * @box: a pixel aligned #ClutterGeometry
+ * @box: a pixel aligned #ClutterActorBox
  *
  * Transforms a 3D paint volume into a 2D bounding box in the
  * same coordinate space as the 3D paint volume.
@@ -908,7 +908,7 @@ _clutter_paint_volume_axis_align (ClutterPaintVolume *pv)
 
   if (G_LIKELY (pv->vertices[0].x == pv->vertices[1].x &&
                 pv->vertices[0].y == pv->vertices[3].y &&
-                pv->vertices[0].z == pv->vertices[4].y))
+                pv->vertices[0].z == pv->vertices[4].z))
     {
       pv->is_axis_aligned = TRUE;
       return;
