@@ -28,7 +28,7 @@
  * @Short_Description: Action to rotate an actor
  *
  * #ClutterRotateAction is a sub-class of #ClutterGestureAction that implements
- * the logic for recognizing rotate gestures.
+ * the logic for recognizing rotate gestures using two touch points.
  *
  * Since: 1.12
  */
@@ -151,7 +151,7 @@ clutter_rotate_action_gesture_progress (ClutterGestureAction *action,
         angle = -angle;
 
       /* Convert radians to degrees */
-      angle = angle * 180.0 / M_PI;
+      angle = angle * 180.0 / G_PI;
 
       g_signal_emit (action, rotate_signals[ROTATE], 0,
                      actor, angle,
