@@ -81,7 +81,6 @@ struct _ClutterZoomActionPrivate
 
   ZoomPoint points[2];
 
-  ClutterPoint initial_focal_point;
   ClutterPoint focal_point;
   ClutterPoint transformed_focal_point;
 
@@ -115,7 +114,7 @@ enum
 
 static guint zoom_signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterZoomAction, clutter_zoom_action, CLUTTER_TYPE_GESTURE_ACTION)
+G_DEFINE_TYPE (ClutterZoomAction, clutter_zoom_action, CLUTTER_TYPE_GESTURE_ACTION);
 
 static void
 capture_point_initial_position (ClutterGestureAction *action,
@@ -177,18 +176,6 @@ clutter_zoom_action_gesture_begin (ClutterGestureAction *action,
                            &priv->initial_scale_x,
                            &priv->initial_scale_y);
 
-  priv->initial_focal_point.x = (priv->points[0].start_x + priv->points[1].start_x) / 2;
-  priv->initial_focal_point.y = (priv->points[0].start_y + priv->points[1].start_y) / 2;
-  clutter_actor_transform_stage_point (actor,
-                                       priv->initial_focal_point.x,
-                                       priv->initial_focal_point.y,
-                                       &priv->transformed_focal_point.x,
-                                       &priv->transformed_focal_point.y);
-
-  clutter_actor_set_pivot_point (actor,
-                                 priv->transformed_focal_point.x / clutter_actor_get_width (actor),
-                                 priv->transformed_focal_point.y / clutter_actor_get_height (actor));
-
   return TRUE;
 }
 
@@ -213,6 +200,11 @@ clutter_zoom_action_gesture_progress (ClutterGestureAction *action,
 
   priv->focal_point.x = (priv->points[0].update_x + priv->points[1].update_x) / 2;
   priv->focal_point.y = (priv->points[0].update_y + priv->points[1].update_y) / 2;
+  priv->transformed_focal_point.x = (priv->points[0].transformed_update_x +
+                                     priv->points[1].transformed_update_x) / 2;
+  priv->transformed_focal_point.y = (priv->points[0].transformed_update_y +
+                                     priv->points[1].transformed_update_y) / 2;
+
 
   new_scale = distance / priv->zoom_initial_distance;
 
@@ -243,16 +235,11 @@ clutter_zoom_action_real_zoom (ClutterZoomAction *action,
                                gdouble            factor)
 {
   ClutterZoomActionPrivate *priv = action->priv;
+  ClutterActor *parent = clutter_actor_get_parent (actor);
   gfloat x, y, z;
   gdouble scale_x, scale_y;
   ClutterVertex out, in;
 
-  in.x = priv->transformed_focal_point.x;
-  in.y = priv->transformed_focal_point.y;
-  in.z = 0;
-
-  clutter_actor_apply_transform_to_point (actor, &in, &out);
-
   clutter_actor_get_scale (actor, &scale_x, &scale_y);
 
   switch (priv->zoom_axis)
@@ -273,10 +260,21 @@ clutter_zoom_action_real_zoom (ClutterZoomAction *action,
       break;
     }
 
-  x = priv->initial_x + priv->focal_point.x - priv->initial_focal_point.x;
-  y = priv->initial_y + priv->focal_point.y - priv->initial_focal_point.y;
-  clutter_actor_get_translation (actor, NULL, NULL, &z);
-  clutter_actor_set_translation (actor, x, y, z);
+
+  in.x = priv->transformed_focal_point.x;
+  in.y = priv->transformed_focal_point.y;
+  in.z = 0;
+
+  clutter_actor_apply_relative_transform_to_point (actor,
+                                                   parent,
+                                                   &in, &out);
+
+
+  clutter_actor_get_translation (actor, &x, &y, &z);
+  clutter_actor_set_translation (actor,
+                                 x + priv->focal_point.x - out.x,
+                                 y + priv->focal_point.y - out.y,
+                                 z);
 
   return TRUE;
 }
@@ -332,6 +330,8 @@ clutter_zoom_action_class_init (ClutterZoomActionClass *klass)
     CLUTTER_GESTURE_ACTION_CLASS (klass);
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (ClutterZoomActionPrivate));
+
   gobject_class->set_property = clutter_zoom_action_set_property;
   gobject_class->get_property = clutter_zoom_action_get_property;
   gobject_class->dispose = clutter_zoom_action_dispose;
@@ -398,7 +398,9 @@ clutter_zoom_action_class_init (ClutterZoomActionClass *klass)
 static void
 clutter_zoom_action_init (ClutterZoomAction *self)
 {
-  self->priv = clutter_zoom_action_get_instance_private (self);
+  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, CLUTTER_TYPE_ZOOM_ACTION,
+                                            ClutterZoomActionPrivate);
+
   self->priv->zoom_axis = CLUTTER_ZOOM_BOTH;
 
   clutter_gesture_action_set_n_touch_points (CLUTTER_GESTURE_ACTION (self), 2);
